# Changelog


## (unreleased)

### Fixes

* FIX: make pypi page formatted. [Pavel Kamaev]

### Optimizations

* OPT: blackify. [Pavel Kamaev]

### Other

* OPT(docs): Added changelog generation. [Ricardo Alves]

* OPT(docs): Improved readme. [Ricardo Alves]



## 0.1.3 (2019-08-01)

### Optimizations

* OPT: preserve order for override keys. [Claudiu Topriceanu]


## 0.1.2 (2019-07-29)

### Optimizations

* OPT: fix travis-ci badge and badges in same line. [Charles David]


## 0.1.0

### New

* NEW: Initial implementation
